Record
======

.. currentmodule:: curies

.. autoclass:: Record
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Record.model_computed_fields
      ~Record.model_config
      ~Record.model_fields

   .. rubric:: Methods Summary

   .. autosummary::

      ~Record.prefix_not_in_synonyms
      ~Record.uri_prefix_not_in_synonyms

   .. rubric:: Attributes Documentation

   .. autoattribute:: model_computed_fields
   .. autoattribute:: model_config
   .. autoattribute:: model_fields

   .. rubric:: Methods Documentation

   .. automethod:: prefix_not_in_synonyms
   .. automethod:: uri_prefix_not_in_synonyms
